# Faint Line Segment Detection Tool
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Overview


## Dependencies
This package depends on `NumPy`, `matplotlib`, and `astropy`.


## References
